Puppet::Type.type(:neutron_mlnx_agent_config).provide(
  :ini_setting,
  :parent => Puppet::Type.type(:openstack_config).provider(:ini_setting)
) do

  def self.file_path
    '/etc/neutron/plugins/mlnx/mlnx_conf.ini'
  end

end
